correios
========

.. image:: https://img.shields.io/pypi/v/correios.svg
    :target: https://pypi.python.org/pypi/correios
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/solidarium/correios.png
   :target: https://travis-ci.org/solidarium/correios
   :alt: Latest Travis CI build status

.. image:: https://coveralls.io/repos/github/solidarium/correios/badge.svg?branch=master
   :target: https://coveralls.io/github/solidarium/correios?branch=master
   :alt: Latest Coveralls coverage status

A client library for Brazilian Correios APIs and services.
